/*
 *  Flash Accel Management Console (FMC)
 *  Copyright (C) 2013, NetApp, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *  Javascript
 *
 *    Farbtastic - Copyright (c) 2010 Matt Farina
 *
 *    jQuery - Copyright (c) 2010 John Resig
 * 
 *    jQuery BBQ - Copyright (c) 2010 "Cowboy" Ben Alman
 *  
 *    jQuery Cookie - Copyright (c) 2006 Klaus Hartl
 *  
 *    jQuery Form - Copyright (c) 2010 Mike Alsup
 *  
 *    jQuery Once - Copyright (c) 2009 Konstantin K\ufffdfer
 *
 *    jQuery UI - Copyright (c) 2010 by the original authors
 *      (http://jqueryui.com/about)
 *
 *    Sizzle.js - Copyright (c) 2010 The Dojo Foundation (http://sizzlejs.com/)
 *
 *  PHP
 *
 *    ArchiveTar - Copyright (c) 1997 - 2008 Vincent Blavet
 */

(function($) {
  
  // A check to ensure that graph is rendered only once
  var famcAnalyticsGraphRendered = false;
  
  Drupal.behaviors.famcAnalytics = {
    'attach': function(context, settings) {
      
      var theme_path = Drupal.settings.theme_path;
      // Preload images
      var imgRefresh = new Image();
      imgRefresh.src = theme_path + "/images/refresh.gif";
      
      // Add the refresh link click events. We use once() to prevent adding of same events multiple times
      $(".metric-refresh-link", context).once('famcAnalytics').click(
        function(e) {
          var $this = $(this);
          var nid = $this.data("nid");
          var type = $this.data("type");
          var elems = $this.data("elements").split(",");
          $this.find("img").attr("src", imgRefresh.src);
          // Reget the views
          $.ajax(
            {
              url: Drupal.settings.basePath + "famc_analytics/get_metrics_content/" + type + "/" + nid,
              dataType: "json",
              success: function(data) {
                // Update the content with the fetched views
                for (var i = 0; i < elems.length; i++) {
                  $("#" + elems[i] + " .view-content").html(data[i]);
                }
                
                $this.find("img").attr("src", Drupal.settings.theme_path + "/images/refresh.png");
                
                // Add table column sorters, if available
                if (window.table_sorter) {
                  table_sorter(); // See JS of mercury_utilities module
                }
                
              },
              error: function(XMLHttpRequest, textStatus, errorThrown) {
                alert(Drupal.t("An error occured while refreshing the metrics."));
                window.location.reload(); // Simply reload the page, the default link behavior
              }
            }
          );
          e.preventDefault();
        }
      );
      
      // Render the analytics graph if data is present and not already rendered
      if (!famcAnalyticsGraphRendered && Drupal.settings.famc_analytics_hist_data) {
        
        var graphData = Drupal.settings.famc_analytics_hist_data;
        var elem = graphData.elem; // The DOM element for the Canvas
        var data = graphData.data; // The data for the graph
        var yaxisLabel = graphData.yaxis; // The yaxis label, i.e. the metric being displayed
	var xaxisLabel = 'Duration'; // Duration
        var ticks = graphData.ticks; // The overriden x-axis ticks

        var options = {
          axes: {
            xaxis: {
	      label: xaxisLabel,
              renderer: $.jqplot.CategoryAxisRenderer,
              labelRenderer: $.jqplot.CanvasAxisLabelRenderer,
              ticks: ticks
            },
            yaxis: {
              label: yaxisLabel,
              min: 0,
              labelRenderer: $.jqplot.CanvasAxisLabelRenderer
            }
          },
	  axesDefaults: {
	      tickOptions: {
		  showGridline: true,
	      }
	  },
	  seriesDefaults: {
             lineWidth: 2,
             markerOptions: {
                size: 4,
             },
	  },
	  grid: {
	      drawGridLines: true,
	  },
          highlighter: {
            show: true,
            sizeAdjust: 5,
            tooltipAxes: 'y',
            useAxesFormatters: false,
            tooltipFormatString: '%.2f'
          }
        }; // jQPlot options
        
        if (graphData.series) {
          // If viewing more than one VM, show the legend
          options.series = graphData.series;
          options.legend = {
            show: true,
            location: 'ne'
          };
        };
        
        $.jqplot(elem, data, options); // jQPlot graph
        
        famcAnalyticsGraphRendered = true; // Prevent re-rendering of graph in case of Drupal ajax events
        
      }
      
    }
  };
  
})(jQuery);

